@@ -19,6 +19,7 @@
 #include "config.h"
 
 #include "common/utility.h"
+#include "common/filesystembase.h"
 #include "version.h"
 
 // Note:  This file must compile without QtGui
@@ -222,7 +223,7 @@ qint64 Utility::freeDiskSpace(const QString &path)
 #elif defined(Q_OS_WIN)
     ULARGE_INTEGER freeBytes;
     freeBytes.QuadPart = 0L;
-    if (GetDiskFreeSpaceEx(reinterpret_cast<const wchar_t *>(path.utf16()), &freeBytes, NULL, NULL)) {
+    if (GetDiskFreeSpaceEx(reinterpret_cast<const wchar_t *>(FileSystem::longWinPath(path).utf16()), &freeBytes, NULL, NULL)) {
         return freeBytes.QuadPart;
     }
 #endif
